<?php
/**
 * Risa Customizer functionality
 *
 * 
 * @package Risa
 * @since Risa 1.0
 */

/**
 * Add postMessage support for site title and description for the Customizer.
 *
 * @since Risa 1.0
 *
 * @param WP_Customize_Manager $wp_customize Customizer object.
 */
function risa_customize_register( $wp_customize ) {
	$color_scheme = risa_get_color_scheme();

	$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	// Add color scheme setting and control.
	$wp_customize->add_setting( 'color_scheme', array(
		'default'           => 'default',
		'sanitize_callback' => 'risa_sanitize_color_scheme',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( 'color_scheme', array(
		'label'    => __( 'Base Color Scheme', 'risa' ),
		'section'  => 'colors',
		'type'     => 'select',
		'choices'  => risa_get_color_scheme_choices(),
		'priority' => 1,
	) );

	// Add custom header and sidebar text color setting and control.
	$wp_customize->add_setting( 'sidebar_textcolor', array(
		'default'           => $color_scheme[4],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sidebar_textcolor', array(
		'label'       => __( 'Header and Sidebar Text Color', 'risa' ),
		'description' => __( 'Applied to the header on small screens and the sidebar on wide screens.', 'risa' ),
		'section'     => 'colors',
	) ) );


	// Add custom menu and sidebar link highlight color setting and control.
	$wp_customize->add_setting( 'sidebar_link_border_color', array(
		'default'           => $color_scheme[7],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sidebar_link_border_color', array(
		'label'       => __( 'Sidebar/Menu Link Highlight Color', 'risa' ),
		'description' => __( 'Applied to the menu highlight and border of links in sidebar.', 'risa' ),
		'section'     => 'colors',
	) ) );


	// Add custom box background color setting and control.
	$wp_customize->add_setting( 'box_background_color', array(
		'default'           => $color_scheme[2],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'box_background_color', array(
		'label'       => __( 'Content Box Background Color', 'risa' ),
		'description' => __( 'Applied to the background of the content box.', 'risa' ),
		'section'     => 'colors',
	) ) );

	// Add custom content text color setting and control.
	$wp_customize->add_setting( 'textcolor', array(
		'default'           => $color_scheme[3],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'textcolor', array(
		'label'       => __( 'Content Text Color', 'risa' ),
		'description' => __( 'Applied to the text of the content box.', 'risa' ),
		'section'     => 'colors',
	) ) );

	// Add custom content link highlight color setting and control.
	$wp_customize->add_setting( 'link_border_color', array(
		'default'           => $color_scheme[6],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_border_color', array(
		'label'       => __( 'Content Link Highlight Color', 'risa' ),
		'description' => __( 'Applied to the menu highlight and border of links in sidebar.', 'risa' ),
		'section'     => 'colors',
	) ) );


	// Remove the core header textcolor control, as it shares the sidebar text color.
	$wp_customize->remove_control( 'header_textcolor' );

	// Add an additional description to the header image section.
	$wp_customize->get_section( 'header_image' )->description = __( 'Applied to the header on small screens and the sidebar on wide screens.', 'risa' );


	/* 
	 * Section Social Share
	 *
	 * All the social share setting
	 */

	$wp_customize->add_section('social_share', array (
		'title'		  => __('Social Share', 'risa'),
		/*'priority'	  => 30,*/
	) );

	$wp_customize->add_setting( 'social_share_twitter', array(
		'default'	=> false,
		'sanitize_callback' => 'risa_sanitize_checkbox',
	) );
	$wp_customize->add_control('social_share_twitter', array(
		'setting'		=> 'social_share_twitter',
		'label'			=> __('Twitter', 'risa'),
		'type'			=> 'checkbox',
		'section'		=> 'social_share',
	) );

	$wp_customize->add_setting( 'social_share_facebook', array(
		'default'	=> false,
		'sanitize_callback' => 'risa_sanitize_checkbox',
	) );
	$wp_customize->add_control('social_share_facebook', array(
		'setting'		=> 'social_share_facebook',
		'label'			=> __('Facebook', 'risa'),
		'type'			=> 'checkbox',
		'section'		=> 'social_share',
	) );

	$wp_customize->add_setting( 'social_share_pinterest', array(
		'default'	=> false,
		'sanitize_callback' => 'risa_sanitize_checkbox',
	) );
	$wp_customize->add_control('social_share_pinterest', array(
		'setting'		=> 'social_share_pinterest',
		'label'			=> __('pinterest', 'risa'),
		'type'			=> 'checkbox',
		'section'		=> 'social_share',
	) );

	$wp_customize->add_setting( 'social_share_linkedin', array(
		'default'	=> false,
		'sanitize_callback' => 'risa_sanitize_checkbox',
	) );
	$wp_customize->add_control('social_share_linkedin', array(
		'setting'		=> 'social_share_linkedin',
		'label'			=> __('linkedin', 'risa'),
		'type'			=> 'checkbox',
		'section'		=> 'social_share',
	) );

	$wp_customize->add_setting( 'social_share_googleplus', array(
		'default'	=> false,
		'sanitize_callback' => 'risa_sanitize_checkbox',
	) );
	$wp_customize->add_control('social_share_googleplus', array(
		'setting'		=> 'social_share_googleplus',
		'label'			=> __('googleplus', 'risa'),
		'type'			=> 'checkbox',
		'section'		=> 'social_share',
	) );

	$wp_customize->add_setting( 'social_share_tumblr', array(
		'default'	=> false,
		'sanitize_callback' => 'risa_sanitize_checkbox',
	) );
	$wp_customize->add_control('social_share_tumblr', array(
		'setting'		=> 'social_share_tumblr',
		'label'			=> __('tumblr', 'risa'),
		'type'			=> 'checkbox',
		'section'		=> 'social_share',
	) );


	$wp_customize->add_setting( 'social_share_digg', array(
		'default'	=> false,
		'sanitize_callback' => 'risa_sanitize_checkbox',
	) );
	$wp_customize->add_control('social_share_digg', array(
		'setting'		=> 'social_share_digg',
		'label'			=> __('digg', 'risa'),
		'type'			=> 'checkbox',
		'section'		=> 'social_share',
	) );

	$wp_customize->add_setting( 'social_share_reddit', array(
		'default'	=> false,
		'sanitize_callback' => 'risa_sanitize_checkbox',
	) );
	$wp_customize->add_control('social_share_reddit', array(
		'setting'		=> 'social_share_reddit',
		'label'			=> __('reddit', 'risa'),
		'type'			=> 'checkbox',
		'section'		=> 'social_share',
	) );

	$wp_customize->add_setting( 'social_share_stumbleupon', array(
		'default'	=> false,
		'sanitize_callback' => 'risa_sanitize_checkbox',
	) );
	$wp_customize->add_control('social_share_stumbleupon', array(
		'setting'		=> 'social_share_stumbleupon',
		'label'			=> __('stumbleupon', 'risa'),
		'type'			=> 'checkbox',
		'section'		=> 'social_share',
	) );

	/* 
	 * Section Footer
	 *
	 * All the footer setting
	 */
	$wp_customize->add_section('footer_setting', array (
		'title'		  => __('Footer Setting', 'risa'),
	) );

	$wp_customize->add_setting( 'footer_credit', array(
		'default'	=> '',
		'sanitize_callback' => 'risa_sanitize_footer_credit',
		'transport' => 'postMessage',
	) );
	$wp_customize->add_control('footer_credit', array(
		'setting'		=> 'footer_credit',
		'label'			=> __('Footer credit text', 'risa'),
		'type'			=> 'textarea',
		'section'		=> 'footer_setting',
	) );

}
add_action( 'customize_register', 'risa_customize_register', 11 );

/**
 * Allowed html tags for footer credit.
 *
 * @since Risa 1.0
 *
 * @return HTML string sanitized with wpkses.
 */
function risa_sanitize_footer_credit($value) {
	$allowed_tags = array(
						'a' => array(
							'href' => array(),
							'title' => array(),
							'rel' => array(),
						),
						'br' => array(),
						'em' => array(),
						'strong' => array(),
						);
	return wp_kses( $value, $allowed_tags );
}

/**
 * Checkbox sanitization callback.
 * 
 * Sanitization callback for 'checkbox' type controls. This callback sanitizes `$checked`
 * as a boolean value, either TRUE or FALSE.
 *
 * @since Risa 1.0
 *
 * @param bool $checked Whether the checkbox is checked.
 * @return bool Whether the checkbox is checked.
 */
function risa_sanitize_checkbox( $checked ) {
	// Boolean check.
	return ( ( isset( $checked ) && true == $checked ) ? true : false );
}

/**
 * Number sanitization callback.
 *
 * - Sanitization: number_absint
 * - Control: number
 * 
 * Sanitization callback for 'number' type text inputs. This callback sanitizes `$number`
 * as an absolute integer (whole number, zero or greater).
 * 
 * NOTE: absint() can be passed directly as `$wp_customize->add_setting()` 'sanitize_callback'.
 * It is wrapped in a callback here merely for example purposes.
 * 
 * @see absint() https://developer.wordpress.org/reference/functions/absint/
 *
 * @param int                  $number  Number to sanitize.
 * @param WP_Customize_Setting $setting Setting instance.
 * @return int Sanitized number; otherwise, the setting default.
 */
function risa_sanitize_number_absint( $number, $setting ) {
	// Ensure $number is an absolute integer (whole number, zero or greater).
	$number = absint( $number );
	
	// If the input is an absolute integer, return it; otherwise, return the default
	return ( $number ? $number : $setting->default );
}

/**
 * Image sanitization callback.
 *
 * Checks the image's file extension and mime type against a whitelist. If they're allowed,
 * send back the filename, otherwise, return the setting default.
 *
 * - Sanitization: image file extension
 * - Control: text, WP_Customize_Image_Control
 * 
 * @see wp_check_filetype() https://developer.wordpress.org/reference/functions/wp_check_filetype/
 *
 * @param string               $image   Image filename.
 * @param WP_Customize_Setting $setting Setting instance.
 * @return string The image filename if the extension is allowed; otherwise, the setting default.
 */
function risa_sanitize_image( $image, $setting ) {
	/*
	 * Array of valid image file types.
	 *
	 * The array includes image mime types that are included in wp_get_mime_types()
	 */
    $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png',
        'bmp'          => 'image/bmp',
        'tif|tiff'     => 'image/tiff',
        'ico'          => 'image/x-icon'
    );
	// Return an array with file extension and mime_type.
    $file = wp_check_filetype( $image, $mimes );
	// If $image has a valid mime_type, return it; otherwise, return the default.
    return ( $file['ext'] ? $image : $setting->default );
}
/**
 * Register color schemes for Risa.
 *
 * Can be filtered with {@see 'risa_color_schemes'}.
 *
 * The order of colors in a colors array:
 * 1. Main Background Color.
 * 2. Sidebar Background Color.
 * 3. Box Background Color.
 * 4. Main Text and Link Color.
 * 5. Sidebar Text and Link Color.
 * 6. Meta Box Background Color.
 *
 * @since Risa 1.0
 *
 * @return array An associative array of color scheme options.
 */
function risa_get_color_schemes() {
	/**
	 * Filter the color schemes registered for use with Risa.
	 *
	 * The default schemes include 'default', 'dark', 'yellow', 'pink', 'purple', and 'blue'.
	 *
	 * @since Risa 1.0
	 *
	 * @param array $schemes {
	 *     Associative array of color schemes data.
	 *
	 *     @type array $slug {
	 *         Associative array of information for setting up the color scheme.
	 *
	 *         @type string $label  Color scheme label.
	 *         @type array  $colors HEX codes for default colors prepended with a hash symbol ('#').
	 *                              Colors are defined in the following order: Main background, sidebar
	 *                              background, box background, main text and link, sidebar text and link,
	 *                              meta box background.
	 *     }
	 * }
	 */
	return apply_filters( 'risa_color_schemes', array(
		'default' => array(
			'label'  => __( 'Default', 'risa' ),
			'colors' => array(
				'#f1f1f1',
				'#ffffff',
				'#ffffff',
				'#333333',
				'#333333',
				'#f7f7f7',
				'#feff93',
				'#feff93',
			),
		),
		'dark'    => array(
			'label'  => __( 'Dark', 'risa' ),
			'colors' => array(
				'#111111',
				'#202020',
				'#202020',
				'#bebebe',
				'#fafafa',
				'#1b1b1b',
				'#87864e',
				'#352d08',
			),
		),
		'yellow'  => array(
			'label'  => __( 'Yellow', 'risa' ),
			'colors' => array(
				'#f4ca16',
				'#ffdf00',
				'#ffffff',
				'#111111',
				'#111111',
				'#f1f1f1',
				'#feff93',
				'#feff93',
			),
		),
		'pink'    => array(
			'label'  => __( 'Pink', 'risa' ),
			'colors' => array(
				'#ffe5d1',
				'#e53b51',
				'#ffffff',
				'#352712',
				'#222222',
				'#f1f1f1',
				'#f7a5a5',
				'#f7a5a5',
			),
		),
		'purple'  => array(
			'label'  => __( 'Purple', 'risa' ),
			'colors' => array(
				'#674970',
				'#2e2256',
				'#ffffff',
				'#2e2256',
				'#ffffff',
				'#f1f1f1',
				'#e599e1',
				'#6d2f65',
			),
		),
		'blue'   => array(
			'label'  => __( 'Blue', 'risa' ),
			'colors' => array(
				'#e9f2f9',
				'#55c3dc',
				'#ffffff',
				'#22313f',
				'#111111',
				'#f1f1f1',
				'#feff93',
				'#feff93',
			),
		),
	) );
}

if ( ! function_exists( 'risa_get_color_scheme' ) ) :
/**
 * Get the current Risa color scheme.
 *
 * @since Risa 1.0
 *
 * @return array An associative array of either the current or default color scheme hex values.
 */
function risa_get_color_scheme() {
	$color_scheme_option = get_theme_mod( 'color_scheme', 'default' );
	$color_schemes       = risa_get_color_schemes();

	if ( array_key_exists( $color_scheme_option, $color_schemes ) ) {
		return $color_schemes[ $color_scheme_option ]['colors'];
	}

	return $color_schemes['default']['colors'];
}
endif; // risa_get_color_scheme

if ( ! function_exists( 'risa_get_color_scheme_choices' ) ) :
/**
 * Returns an array of color scheme choices registered for Risa.
 *
 * @since Risa 1.0
 *
 * @return array Array of color schemes.
 */
function risa_get_color_scheme_choices() {
	$color_schemes                = risa_get_color_schemes();
	$color_scheme_control_options = array();

	foreach ( $color_schemes as $color_scheme => $value ) {
		$color_scheme_control_options[ $color_scheme ] = $value['label'];
	}

	return $color_scheme_control_options;
}
endif; // risa_get_color_scheme_choices

if ( ! function_exists( 'risa_sanitize_color_scheme' ) ) :
/**
 * Sanitization callback for color schemes.
 *
 * @since Risa 1.0
 *
 * @param string $value Color scheme name value.
 * @return string Color scheme name.
 */
function risa_sanitize_color_scheme( $value ) {
	$color_schemes = risa_get_color_scheme_choices();

	if ( ! array_key_exists( $value, $color_schemes ) ) {
		$value = 'default';
	}

	return $value;
}
endif; // risa_sanitize_color_scheme

/**
 * Enqueues front-end CSS for color scheme.
 *
 * @since Risa 1.0
 *
 * @see wp_add_inline_style()
 */
function risa_color_scheme_css() {
	$color_scheme_option = get_theme_mod( 'color_scheme', 'default' );

	// Don't do anything if the default color scheme is selected.
	if ( 'default' === $color_scheme_option ) {
		return;
	}

	$color_scheme = risa_get_color_scheme();

	// Convert main and sidebar text hex color to rgba.
	$color_textcolor_rgb         = risa_hex2rgb( $color_scheme[3] );
	$color_sidebar_textcolor_rgb = risa_hex2rgb( $color_scheme[4] );
	$colors = array(
		'background_color'            => $color_scheme[0],
		'header_background_color'     => $color_scheme[1],
		'box_background_color'        => $color_scheme[2],
		'textcolor'                   => $color_scheme[3],
		'secondary_textcolor'         => vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.7)', $color_textcolor_rgb ),
		'border_color'                => vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.2)', $color_textcolor_rgb ),
		'border_focus_color'          => vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.5)', $color_textcolor_rgb ),
		'sidebar_textcolor'           => $color_scheme[4],
		'sidebar_border_color'        => vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.2)', $color_sidebar_textcolor_rgb ),
		'sidebar_border_focus_color'  => vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.5)', $color_sidebar_textcolor_rgb ),
		'secondary_sidebar_textcolor' => vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.7)', $color_sidebar_textcolor_rgb ),
		'meta_box_background_color'   => $color_scheme[5],
		'link_border_color'			  => $color_scheme[6],
		'sidebar_link_border_color'	  => $color_scheme[7],
	);

	$color_scheme_css = risa_get_color_scheme_css( $colors );

	wp_add_inline_style( 'risa-style', $color_scheme_css );
}
add_action( 'wp_enqueue_scripts', 'risa_color_scheme_css' );

/**
 * Binds JS listener to make Customizer color_scheme control.
 *
 * Passes color scheme data as colorScheme global.
 *
 * @since Risa 1.0
 */
function risa_customize_control_js() {
	wp_enqueue_script( 'color-scheme-control', get_template_directory_uri() . '/js/color-scheme-control.js', array( 'customize-controls', 'iris', 'underscore', 'wp-util' ), '20141216', true );
	wp_localize_script( 'color-scheme-control', 'colorScheme', risa_get_color_schemes() );
}
add_action( 'customize_controls_enqueue_scripts', 'risa_customize_control_js' );

/**
 * Binds JS handlers to make the Customizer preview reload changes asynchronously.
 *
 * @since Risa 1.0
 */
function risa_customize_preview_js() {
	wp_enqueue_script( 'risa-customize-preview', get_template_directory_uri() . '/js/customize-preview.js', array( 'customize-preview' ), '20141216', true );
}
add_action( 'customize_preview_init', 'risa_customize_preview_js' );

/**
 * Returns CSS for the color schemes.
 *
 * @since Risa 1.0
 *
 * @param array $colors Color scheme colors.
 * @return string Color scheme CSS.
 */
function risa_get_color_scheme_css( $colors ) {
	$colors = wp_parse_args( $colors, array(
		'background_color'            => '',
		'header_background_color'     => '',
		'box_background_color'        => '',
		'textcolor'                   => '',
		'secondary_textcolor'         => '',
		'border_color'                => '',
		'border_focus_color'          => '',
		'sidebar_textcolor'           => '',
		'sidebar_border_color'        => '',
		'sidebar_border_focus_color'  => '',
		'secondary_sidebar_textcolor' => '',
		'meta_box_background_color'   => '',
		'link_border_color'			  => '',
		'sidebar_link_border_color'	  => '',
	) );

	$css = <<<CSS
	/* Color Scheme */

	/* Background Color */
	body {
		background-color: {$colors['background_color']};
	}

	/* Box Background Color */
	.post-navigation,
	.pagination,
	.secondary,
	.hentry,
	.page-header,
	.page-content,
	.comments-area,
	.widecolumn,
	.widget.related-posts {
		background-color: {$colors['box_background_color']};
	}

	/* Box Background Color */
	button,
	input[type="button"],
	input[type="reset"],
	input[type="submit"],
	.pagination .prev,
	.pagination .next,
	.widget_calendar tbody a,
	.widget_calendar tbody a:hover,
	.widget_calendar tbody a:focus,
	.page-links a,
	.page-links a:hover,
	.page-links a:focus,
	.sticky-post {
		color: {$colors['box_background_color']};
	}

	/* Main Text Color */
	button,
	input[type="button"],
	input[type="reset"],
	input[type="submit"],
	.pagination .prev,
	.pagination .next,
	.widget_calendar tbody a,
	.page-links a,
	.sticky-post {
		background-color: {$colors['textcolor']};
	}

	/* Main Text Color */
	body,
	blockquote cite,
	blockquote small,
	a,
	.dropdown-toggle:after,
	.image-navigation a:hover,
	.image-navigation a:focus,
	.comment-navigation a:hover,
	.comment-navigation a:focus,
	.widget-title,
	.entry-footer a:hover,
	.entry-footer a:focus,
	.comment-metadata a:hover,
	.comment-metadata a:focus,
	.pingback .edit-link a:hover,
	.pingback .edit-link a:focus,
	.comment-list .reply a:hover,
	.comment-list .reply a:focus,
	.site-info a:hover,
	.site-info a:focus {
		color: {$colors['textcolor']};
	}

	/* Main Text Color */
	.entry-content a,
	.entry-summary a,
	.page-content a,
	.comment-content a,
	.pingback .comment-body > a,
	.author-description a,
	.taxonomy-description a,
	.textwidget a,
	.entry-footer a:hover,
	.comment-metadata a:hover,
	.pingback .edit-link a:hover,
	.comment-list .reply a:hover,
	.site-info a:hover {
		border-color: {$colors['textcolor']};
	}

	/* Secondary Text Color */
	button:hover,
	button:focus,
	input[type="button"]:hover,
	input[type="button"]:focus,
	input[type="reset"]:hover,
	input[type="reset"]:focus,
	input[type="submit"]:hover,
	input[type="submit"]:focus,
	.pagination .prev:hover,
	.pagination .prev:focus,
	.pagination .next:hover,
	.pagination .next:focus,
	.widget_calendar tbody a:hover,
	.widget_calendar tbody a:focus,
	.page-links a:hover,
	.page-links a:focus {
		background-color: {$colors['textcolor']}; /* Fallback for IE7 and IE8 */
		background-color: {$colors['secondary_textcolor']};
	}

	/* Secondary Text Color */
	blockquote,
	a:hover,
	a:focus,
	.main-navigation .menu-item-description,
	.post-navigation .meta-nav,
	.post-navigation a:hover .post-title,
	.post-navigation a:focus .post-title,
	.image-navigation,
	.image-navigation a,
	.comment-navigation,
	.comment-navigation a,
	.author-heading,
	.entry-meta,
	.entry-meta a,
	.entry-footer,
	.entry-footer a,
	.taxonomy-description,
	.page-links > .page-links-title,
	.entry-caption,
	.comment-author,
	.comment-metadata,
	.comment-metadata a,
	.pingback .edit-link,
	.pingback .edit-link a,
	.post-password-form label,
	.comment-form label,
	.comment-notes,
	.comment-awaiting-moderation,
	.logged-in-as,
	.form-allowed-tags,
	.no-comments,
	.site-info,
	.site-info a,
	.wp-caption-text,
	.gallery-caption,
	.comment-list .reply a,
	.widecolumn label,
	.widecolumn .mu_register label {
		color: {$colors['textcolor']}; /* Fallback for IE7 and IE8 */
		color: {$colors['secondary_textcolor']};
	}

	/* Secondary Text Color */
	blockquote,
	.logged-in-as a:hover,
	.comment-author a:hover {
		border-color: {$colors['textcolor']}; /* Fallback for IE7 and IE8 */
		border-color: {$colors['secondary_textcolor']};
	}

	/* Border Color */
	hr,
	.dropdown-toggle:hover,
	.dropdown-toggle:focus {
		background-color: {$colors['textcolor']}; /* Fallback for IE7 and IE8 */
		background-color: {$colors['border_color']};
	}

	/* Border Color */
	pre,
	abbr[title],
	table,
	th,
	td,
	input,
	textarea,
	.main-navigation ul,
	.main-navigation li,
	.post-navigation,
	.post-navigation div + div,
	.pagination,
	.comment-navigation,
	.widget li,
	.widget_categories .children,
	.widget_nav_menu .sub-menu,
	.widget_pages .children,
	.site-header,
	.site-footer,
	.hentry + .hentry,
	.author-info,
	.entry-content .page-links a,
	.page-links > span,
	.page-header,
	.comments-area,
	.comment-list + .comment-respond,
	.comment-list article,
	.comment-list .pingback,
	.comment-list .trackback,
	.comment-list .reply a,
	.no-comments,
	.social-share button,
	.entry-footer {
		border-color: {$colors['textcolor']}; /* Fallback for IE7 and IE8 */
		border-color: {$colors['border_color']};
	}

	/* Border Focus Color */
	a:focus,
	button:focus,
	input:focus {
		outline-color: {$colors['textcolor']}; /* Fallback for IE7 and IE8 */
		outline-color: {$colors['border_focus_color']};
	}

	input:focus,
	textarea:focus {
		border-color: {$colors['textcolor']}; /* Fallback for IE7 and IE8 */
		border-color: {$colors['border_focus_color']};
	}

	/* Sidebar Link Color */
	.secondary-toggle:before {
		color: {$colors['sidebar_textcolor']};
	}

	.site-title a,
	.site-description {
		color: {$colors['sidebar_textcolor']};
	}

	/* Sidebar Text Color */
	.site-title a:hover,
	.site-title a:focus {
		color: {$colors['secondary_sidebar_textcolor']};
	}

	/* Sidebar Border Color */
	.secondary-toggle {
		border-color: {$colors['sidebar_textcolor']}; /* Fallback for IE7 and IE8 */
		border-color: {$colors['sidebar_border_color']};
	}

	/* Sidebar Border Focus Color */
	.secondary-toggle:hover,
	.secondary-toggle:focus {
		border-color: {$colors['sidebar_textcolor']}; /* Fallback for IE7 and IE8 */
		border-color: {$colors['sidebar_border_focus_color']};
	}

	.site-title a {
		outline-color: {$colors['sidebar_textcolor']}; /* Fallback for IE7 and IE8 */
		outline-color: {$colors['sidebar_border_focus_color']};
	}

	@media screen and (min-width: 38.75em) {
		/* Main Text Color */
		.page-header {
			border-color: {$colors['textcolor']};
		}
	}

	/* Make sure its transparent on desktop */
	.site-header,
	.secondary {
		background-color: transparent;
	}

	/* Sidebar Background Color ===============*/
	.widget button,
	.widget input[type="button"],
	.widget input[type="reset"],
	.widget input[type="submit"],
	.widget_calendar tbody a,
	.widget_calendar tbody a:hover,
	.widget_calendar tbody a:focus {
		color: {$colors['header_background_color']};
	}

	/* Sidebar Link Color */
	.secondary,
	.secondary a,
	.dropdown-toggle:after,
	.widget-title,
	.widget blockquote cite,
	.widget blockquote small {
		color: {$colors['sidebar_textcolor']};
	}

	.widget button,
	.widget input[type="button"],
	.widget input[type="reset"],
	.widget input[type="submit"],
	.widget_calendar tbody a {
		background-color: {$colors['sidebar_textcolor']};
	}

	.textwidget a {
		border-color: {$colors['sidebar_textcolor']};
	}

	/* Sidebar Text Color */
	.secondary a:hover,
	.secondary a:focus,
	.main-navigation .menu-item-description,
	.social-navigation a,
	.widget blockquote,
	.widget .wp-caption-text,
	.widget .gallery-caption,
	.widget .entry-meta,
	.widget .entry-meta a,
	.widget .tweet-meta a {
		color: {$colors['secondary_sidebar_textcolor']};
	}

	.widget button:hover,
	.widget button:focus,
	.widget input[type="button"]:hover,
	.widget input[type="button"]:focus,
	.widget input[type="reset"]:hover,
	.widget input[type="reset"]:focus,
	.widget input[type="submit"]:hover,
	.widget input[type="submit"]:focus,
	.widget_calendar tbody a:hover,
	.widget_calendar tbody a:focus {
		background-color: {$colors['secondary_sidebar_textcolor']};
	}

	.widget blockquote {
		border-color: {$colors['secondary_sidebar_textcolor']};
	}

	/* Sidebar Border Color */
	.main-navigation,
	.social-navigation,
	.social-navigation a,
	.secondary-toggle,
	.widget,
	.widget input,
	.widget textarea,
	.widget table,
	.widget th,
	.widget td,
	.widget pre,
	.widget li,
	.widget_categories .children,
	.widget_nav_menu .sub-menu,
	.widget_pages .children,
	.widget abbr[title] {
		border-color: {$colors['sidebar_border_color']};
	}

	.dropdown-toggle:hover,
	.dropdown-toggle:focus,
	.widget hr {
		background-color: {$colors['sidebar_border_color']};
	}

	.widget input:focus,
	.widget textarea:focus {
		border-color: {$colors['sidebar_border_focus_color']};
	}

	.sidebar a:focus,
	.dropdown-toggle:focus {
		outline-color: {$colors['sidebar_border_focus_color']};
	}

	/* Link Border */
	.entry-content a,
	.entry-summary a,
	.page-content a,
	.comment-content a,
	.pingback .comment-body > a,
	.widget p a {
		border-color: {$colors['link_border_color']};
	}

	.entry-content .more-link, 
	.author-description .author-link{
		border-color: {$colors['link_border_color']};
		box-shadow: 0 -.5em {$colors['link_border_color']} inset;
	}

	/* Sidebar Link Border */
	.main-navigation a {
		border-color: {$colors['sidebar_link_border_color']};
		box-shadow: 0 -.625em {$colors['sidebar_link_border_color']} inset;
	}

	.widget p a {
		border-color: {$colors['sidebar_link_border_color']};
	}

CSS;

	return $css;
}

/**
 * Output an Underscore template for generating CSS for the color scheme.
 *
 * The template generates the css dynamically for instant display in the Customizer
 * preview.
 *
 * @since Risa 1.0
 */
function risa_color_scheme_css_template() {
	$colors = array(
		'background_color'            => '{{ data.background_color }}',
		'header_background_color'     => '{{ data.header_background_color }}',
		'box_background_color'        => '{{ data.box_background_color }}',
		'textcolor'                   => '{{ data.textcolor }}',
		'secondary_textcolor'         => '{{ data.secondary_textcolor }}',
		'border_color'                => '{{ data.border_color }}',
		'border_focus_color'          => '{{ data.border_focus_color }}',
		'sidebar_textcolor'           => '{{ data.sidebar_textcolor }}',
		'sidebar_border_color'        => '{{ data.sidebar_border_color }}',
		'sidebar_border_focus_color'  => '{{ data.sidebar_border_focus_color }}',
		'secondary_sidebar_textcolor' => '{{ data.secondary_sidebar_textcolor }}',
		'meta_box_background_color'   => '{{ data.meta_box_background_color }}',
		'link_border_color'   		  => '{{ data.link_border_color }}',
		'sidebar_link_border_color'   => '{{ data.sidebar_link_border_color }}',
	);
	?>
	<script type="text/html" id="tmpl-risa-color-scheme">
		<?php echo risa_get_color_scheme_css( $colors ); ?>
	</script>
	<?php
}
add_action( 'customize_controls_print_footer_scripts', 'risa_color_scheme_css_template' );
