<?php
/**
 * Custom template tags for Risa
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * 
 * @package Risa
 * @since Risa 1.0
 */

if ( ! function_exists( 'risa_comment_nav' ) ) :
/**
 * Display navigation to next/previous comments when applicable.
 *
 * @since Risa 1.0
 */
function risa_comment_nav() {
	// Are there comments to navigate through?
	if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
	?>
	<nav class="navigation comment-navigation" role="navigation">
		<h2 class="screen-reader-text"><?php _e( 'Comment navigation', 'risa' ); ?></h2>
		<div class="nav-links">
			<?php
				if ( $prev_link = get_previous_comments_link( __( 'Older Comments', 'risa' ) ) ) :
					printf( '<div class="nav-previous">%s</div>', $prev_link );
				endif;

				if ( $next_link = get_next_comments_link( __( 'Newer Comments', 'risa' ) ) ) :
					printf( '<div class="nav-next">%s</div>', $next_link );
				endif;
			?>
		</div><!-- .nav-links -->
	</nav><!-- .comment-navigation -->
	<?php
	endif;
}
endif;

if ( ! function_exists( 'risa_entry_meta' ) ) :
/**
 * Prints HTML with meta information for the categories, tags.
 *
 * @since Risa 1.0
 */
function risa_entry_meta() {
	if ( is_sticky() && is_home() && ! is_paged() ) {
		printf( '<span class="sticky-post">%s</span>', __( 'Featured', 'risa' ) );
	}

	$format = get_post_format();
	if ( current_theme_supports( 'post-formats', $format ) ) {
		printf( '<span class="entry-format">%1$s<a href="%2$s">%3$s</a></span>',
			sprintf( '<span class="screen-reader-text">%s </span>', _x( 'Format', 'Used before post format.', 'risa' ) ),
			esc_url( get_post_format_link( $format ) ),
			get_post_format_string( $format )
		);
	}

	if ( in_array( get_post_type(), array( 'post', 'attachment' ) ) ) {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			get_the_date(),
			esc_attr( get_the_modified_date( 'c' ) ),
			get_the_modified_date()
		);

		/*printf( '<span class="posted-on"><span class="screen-reader-text">%1$s </span><a href="%2$s" rel="bookmark">%3$s</a></span>',
			_x( 'Posted on', 'Used before publish date.', 'risa' ),
			esc_url( get_permalink() ),
			$time_string
		);*/
	}

	if ( 'post' == get_post_type() ) {
		if ( is_singular() || is_multi_author() ) {
			/*printf( '<span class="byline"><span class="author vcard"><span class="screen-reader-text">%1$s </span><a class="url fn n" href="%2$s">%3$s</a></span></span>',
				_x( 'Author', 'Used before post author name.', 'risa' ),
				esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
				get_the_author()
			);*/
		}

		$categories_list = get_the_category_list( _x( ', ', 'Used between list items, there is a space after the comma.', 'risa' ) );
		if ( $categories_list && risa_categorized_blog() ) {
			printf( '<span class="cat-links"><span class="screen-reader-text">%1$s </span>%2$s</span>',
				_x( 'Categories', 'Used before category names.', 'risa' ),
				$categories_list
			);
		}

		$tags_list = get_the_tag_list( '', _x( ', ', 'Used between list items, there is a space after the comma.', 'risa' ) );
		if ( $tags_list ) {
			printf( '<span class="tags-links"><span class="screen-reader-text">%1$s </span>%2$s</span>',
				_x( 'Tags', 'Used before tag names.', 'risa' ),
				$tags_list
			);
		}
	}

	if ( is_attachment() && wp_attachment_is_image() ) {
		// Retrieve attachment metadata.
		$metadata = wp_get_attachment_metadata();

		printf( '<span class="full-size-link"><span class="screen-reader-text">%1$s </span><a href="%2$s">%3$s &times; %4$s</a></span>',
			_x( 'Full size', 'Used before full size attachment link.', 'risa' ),
			esc_url( wp_get_attachment_url() ),
			$metadata['width'],
			$metadata['height']
		);
	}

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link">';
		/* translators: %s: post title */
		comments_popup_link( sprintf( __( 'Leave a comment<span class="screen-reader-text"> on %s</span>', 'risa' ), get_the_title() ) );
		echo '</span>';
	}
}
endif;

if ( ! function_exists( 'risa_entry_meta_header' ) ) :
/**
 * Prints HTML with meta information for the categories, tags.
 *
 * @since Risa 1.0
 */
function risa_entry_meta_header() {

	if ( 'post' == get_post_type() ) {

		echo get_avatar( get_the_author_meta( 'user_email' ), 40 );

		printf( '<span class="byline"><span class="author vcard"><span class="screen-reader-text">%1$s </span><a class="url fn n" href="%2$s">%3$s</a></span></span>',
			_x( 'Author', 'Used before post author name.', 'risa' ),
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			get_the_author()
		);
	}

	if ( in_array( get_post_type(), array( 'post', 'attachment' ) ) ) {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			get_the_date(),
			esc_attr( get_the_modified_date( 'c' ) ),
			get_the_modified_date()
		);

		printf( '<span class="posted-on"><span class="screen-reader-text">%1$s </span><a href="%2$s" rel="bookmark">%3$s</a></span>',
			_x( 'Posted on', 'Used before publish date.', 'risa' ),
			esc_url( get_permalink() ),
			$time_string
		);
	}

}
endif;

/**
 * Determine whether blog/site has more than one category.
 *
 * @since Risa 1.0
 *
 * @return bool True of there is more than one category, false otherwise.
 */
function risa_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'risa_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'risa_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so risa_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so risa_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in {@see risa_categorized_blog()}.
 *
 * @since Risa 1.0
 */
function risa_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'risa_categories' );
}
add_action( 'edit_category', 'risa_category_transient_flusher' );
add_action( 'save_post',     'risa_category_transient_flusher' );

if ( ! function_exists( 'risa_post_thumbnail' ) ) :
/**
 * Display an optional post thumbnail.
 *
 * Wraps the post thumbnail in an anchor element on index views, or a div
 * element when on single views.
 *
 * @since Risa 1.0
 */
function risa_post_thumbnail() {
	if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
		return;
	}

	if ( is_singular() ) :
	?>

	<div class="post-thumbnail">
		<?php the_post_thumbnail(); ?>
	</div><!-- .post-thumbnail -->

	<?php else : ?>

	<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
		<?php
			the_post_thumbnail( 'post-thumbnail', array( 'alt' => get_the_title() ) );
		?>
	</a>

	<?php endif; // End is_singular()
}
endif;

if ( ! function_exists( 'risa_get_link_url' ) ) :
/**
 * Return the post URL.
 *
 * Falls back to the post permalink if no URL is found in the post.
 *
 * @since Risa 1.0
 *
 * @see get_url_in_content()
 *
 * @return string The Link format URL.
 */
function risa_get_link_url() {
	$has_url = get_url_in_content( get_the_content() );

	return $has_url ? $has_url : apply_filters( 'the_permalink', get_permalink() );
}
endif;

if ( ! function_exists( 'risa_excerpt_more' ) && ! is_admin() ) :
/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ... and a 'Continue reading' link.
 *
 * @since Risa 1.0
 *
 * @return string 'Continue reading' link prepended with an ellipsis.
 */
function risa_excerpt_more( $more ) {
	$link = sprintf( '<a href="%1$s" class="more-link">%2$s</a>',
		esc_url( get_permalink( get_the_ID() ) ),
		/* translators: %s: Name of current post */
		sprintf( __( 'Continue reading %s', 'risa' ), '<span class="screen-reader-text">' . get_the_title( get_the_ID() ) . '</span>' )
		);
	return ' &hellip; ' . $link;
}
add_filter( 'excerpt_more', 'risa_excerpt_more' );
endif;


if ( ! function_exists( 'risa_related_posts' ) ) :
/**
 * Get first blockquote from the post content
 * used for quote post format
 * 
 * @since Karen 1.0
 */
function risa_related_posts() {
	//$related_by = get_theme_mod('related_post_by', 'tags');

	$current_id = get_the_ID();
	$tags = wp_get_post_tags( $current_id, array( 'fields' => 'ids' ) );
	//print_r($current_id);
	$query = array (
			'posts__not_in' => array ( $current_id ),
			'tag__in' => $tags,
			'posts_per_page' => 4,
		);

	$result = new WP_Query( $query );
	
	if ( $result->have_posts() ) :
	?>
		<div id="related-posts" class="related-posts widget widget-recent-posts">
			<h3 class="related-title widget-title"><span><?php _e('Related Posts', 'risa'); ?></span></h3>
			<ul>
			<?php while ( $result->have_posts() ) : $result->the_post() ?>
				<li>
				<?php if ( has_post_thumbnail() ) : ?>
					<a class="post-thumbnail alignleft" href="<?php the_permalink(); ?>" aria-hidden="true">
						<?php the_post_thumbnail( 'thumbnail', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?>
					</a>
				<?php endif; ?>
					<span class="entry-meta"><?php echo get_the_date(); ?></span>
					<span class="entry-title"><a href="<?php the_permalink(); ?>"><?php get_the_title() ? the_title() : the_ID(); ?></a></span>
				</li>
			<?php endwhile; ?>
			</ul>
		</div>
	<?php
	endif;	
	wp_reset_postdata();
}
endif;


if ( ! function_exists( 'risa_social_share' ) ) :
/**
 * Social media share
 *
 */
function risa_social_share(){
	global $post;
	$services = array(
		'twitter'     => __('Twitter', 'risa'),
		'facebook'    => __('Facebook', 'risa'),
		'pinterest'   => __('Pinterest', 'risa'),
		'linkedin'    => __('Linkedin', 'risa'),
		'googleplus'  => __('Google+', 'risa'),
		'tumblr'      => __('Tumblr', 'risa'),
		'blogger'     => __('Blogger', 'risa'),
		'digg'        => __('Digg', 'risa'),
		'reddit'      => __('Reddit', 'risa'),
		'stumbleupon' => __('Stumble', 'risa'),
		'delicious'   => __('Delicious', 'risa'));
	$print = '<div id="social-share" class="social-share">';
	$print .= '<h6 class="social-share-title"><span>';
	$print .= __('Share This', 'risa');
	$print .= '</span></h6>';
	$print .= '<div>';
	$number_button = 0;
	foreach ( $services as $service=>$label ){
		if ( get_theme_mod('social_share_' . $service) ){
			$print .= '<button class="icon-'. $service. ' s_'. $service . ' share">';
			$print .= '<span class="screen-reader-text">'. $label .'</span><span class="counter"></span>';
			$print .= '</button>';
			$number_button ++;
		}
	}
	$print .= '</div></div>';

	if ( $number_button > 0 ) echo $print;
}

endif;

